@@ -64,7 +64,7 @@ namespace std {
     void _destroy(){
       if (_taille>0){ 
 	if (_begin_immediate_vect) {
-	  // std::cerr << "delete " << _taille << endl;
+	  // std::cerr << "delete " << _taille << '\n';
 	  delete [] _begin_immediate_vect; 
 	}
       }
@@ -229,8 +229,14 @@ namespace std {
 	// if p0 is a vector element and the vector is realloced
 	_Tp p(p0); 
 	_realloc(_taille?-2*_taille:1);
-	*(_begin_immediate_vect+_taille)=p;
-	++_taille;
+	if (_taille==immvector_max){
+	  *(_begin_immediate_vect)=p;
+	  _taille=1;
+	}
+	else {
+	  *(_begin_immediate_vect+_taille)=p;
+	  ++_taille;
+	}
 	return;
       }
       if (_taille==immvector_max) 
@@ -265,7 +271,7 @@ namespace std {
     void clear(){ 
       if (_taille>0 &&_begin_immediate_vect){
 	if (_taille!=immvector_max){
-	  for (unsigned i=0;i<_taille;++i)
+	  for (int i=0;i<_taille;++i)
 	    *(_begin_immediate_vect+i)=_Tp();
 	  _taille=immvector_max;
 	}
